c This program computes the energies of the scaled airy problem using sin
c    functions as the basis set.
c
c
      program Chap_6_airy
      implicit real*8 (a-h,o-z)
      parameter(nbasis = 100)
      dimension ham(nbasis,nbasis), eigv(nbasis), work(nbasis*4),
     1  airy(5)
c define pi
      pi = 2.0d0*dasin(1.d0)
c set the first 5 zeros of the airy function
      airy(1) = 2.33810741045976704d0/2.d0**(1.d0/3.d0)
      airy(2) = 4.08794944413097062d0/2.d0**(1.d0/3.d0)
      airy(3) = 5.52055982809555106d0/2.d0**(1.d0/3.d0)
      airy(4) = 6.786708090071759d0/2.d0**(1.d0/3.d0)
      airy(5) = 7.94413358712085312d0/2.d0**(1.d0/3.d0)
c set the c-scale
      csc = 10.d0
c cycle through different number of basis functions
      do 10 ibas = 1, nbasis
c initialize all of the 0's of the hamiltonian matrix
       do 11 j = 1, ibas
       do 11 k = 1, ibas
       ham(k,j) = 0.d0
 11    continue
c fill the diagonal elements
       do 12 j = 1, ibas
       ham(j,j) = 0.5d0*(pi*j/csc)**2 + 0.5d0*csc
 12    continue
c fill the off diagonal elements
       do 13 j = 1, ibas-1
       do 14 k = j+1, ibas
        if(mod(j+k,2) .eq. 1) then
        ham(k,j) = 2.0d0*csc*(1.d0/(j+k)**2-1.d0/(k-j)**2)/pi**2
        ham(j,k) = ham(k,j)
        end if
 14    continue
 13    continue

c now diagonalize H
      nd = ibas
      lda = nbasis
      lwork = nbasis*4
      call dsyev('v','u',nd,ham,lda,eigv,work,lwork,info)
c      write(6,*) info
      write(8,900)ibas,(eigv(j),j=1,12)
       do 15 j = ibas+1,5
       eigv(j) = 0.d0
 15    continue
      write(10,900)ibas,(abs(eigv(j)-airy(j))/airy(j),j=1,5)
c output the ground state function for the first 10 basis
       if(ibas .le. 10) then
       fac = 1.0d0
        if(ham(1,1) .le. 0.d0) fac=-1.d0
c set the normalization constant of the sin's
       fac = fac*dsqrt(2.d0/csc)
c set the number of points
       npts = 200
c set the x-spacing for the plot
       dx = csc/npts
        do 20 jx = 0, npts
        x = dx*jx
c compute the function by superposing the states
        fun = 0.d0
         do 21 n = 1, ibas
         fun = fun + fac*sin(n*pi*x/csc)*ham(n,1)
 21      continue
c print out the functions
        write(30+ibas,901)x,fun
 20     continue
       end if
 10   continue

 900  format(i4,30(1pe12.4))
 901  format(30(1pe12.4))
      stop 'end of program'
      end
      